##  Overview
Using Python with [GraphQL](https://help.sap.com/docs/leanix/ea/graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD "Get started with the SAP LeanIX GraphQL API.") allows you to efficiently retrieve and manipulate data. You can develop scripts that take full advantage of GraphQL's ability to fetch complex, interrelated data with a single request.
In this tutorial, you will learn how to create and run GraphQL queries and mutations using Python scripts. To provide examples, we will create the following scripts:
  * A script with a GraphQL query that retrieves Application Fact Sheets
  * A script with a GraphQL mutation that adds a comment to a specific Fact Sheet
